
#ifndef PLUGIN_GLM_HEADER_H
#define PLUGIN_GLM_HEADER_H

// header for GLM
//
struct GLM_Header
{
	int   GLMDataType; // 0: FMR-STC, 1: VMR-VTC, 2: SRF-MTC

	int   RFXGLM;
	int   NrOfSubjectsRFXGLM;           // only set if RFXGLM
	int   NrOfSubjectPredictorsRFXGLM;  // only set if RFXGLM

	int   CorrectedForSerialCorrelations;  // 0: none, 1: AR(1), 2: AR(2)

	// following values are set for all GLM data types as indicated
	int   DimX; // FMR-GLM: no. of slice columns, VTC-GLM: (XEndVTC - XStartVTC)/Resolution,  MTC-GLM: NrOfVertices
	int   DimY; // FMR-GLM: no. of slice rows,    VTC-GLM: (YEndVTC - YStartVTC)/Resolution,  MTC-GLM: 1
	int   DimZ; // FMR-GLM: no. of slices,        VTC-GLM: (ZEndVTC - ZStartVTC)/Resolution,  MTC-GLM: 1

	// following values only set if VMR-VTC GLM (GLMDAtaType "1")
	int   XStart;
	int   XEnd;
	int   YStart;
	int   YEnd;
	int   ZStart;
	int   ZEnd;
	int   Resolution; // iso-dimension of functional voxel with respect to anatomical data (e.g. "3" implies 3x3x3 anatomical voxels per functional voxel)

	// following value is only set if SRF-MTC GLM (GLMDAtaType "2")
	int   NrOfVertices;

	int   NrOfTimePoints;     // overall nr of time points in original data used to compute GLM
	int   NrOfPredictors;     // nr of all predictors including confounds
	int   NrOfCounfounds;     // nr of confound predictors (nr of main preds = nr of all - nr of confounds)
	int   NrOfStudies;        // overall number of analyzed studies (sum of runs across all subjects)
	int   SeparatePredictors; // "0" no separate preds, "1" separate preds for each study, "2" separate preds for each subject
	int   PSCTransformation;  // "1" percent signal change transformation has been computed for each study
	int   ZTransformation;    // "1" z transformation has been computed for each study ("2" baseline-only z transformation)

	int   CortexBasedStatistics; // "1" a (cortex) mask was used
	int   NrOfVoxelsForBonfCorrection; // either TAL space voxels or voxels in mask (if mask used)
	char  CortexMaskFile[260];
	char  GLMFileName[260];

	float **DesignMatrix;     // pointer to design matrix: X[NrOfTimePoints][NrOfPredictors]
	float **iXX;              // pointer to inverted square matrix X transposed * X: iXX[NrOfPredictors][NrOfPredictors]
};

// header for defined GLM contrasts
//
struct GLMContrast_Header
{
	// access info about currently overlayed contrast (if any)
	int   NrOfContrastPredictors;
	int   NrOfContrasts;
	int   CurrentContrastIndex;
	float **ContrastVectors;
	char  **ContrastNames;
};

#endif // PLUGIN_GLM_HEADER_H
